@@ -75,10 +75,6 @@ class CallStackElem(object):
 				# Copy the inbound data into the instance DB
 				# and add the outbound parameters to the list.
 				for param in parameters:
-					#TODO param interface and instanceDB assignments should
-					#     be done at translation time.
-					param.interface, param.instanceDB =\
-						blockInterface, instanceDB
 					if param.isOutbound:
 						# This is an outbound parameter.
 						self.__outboundParams.append(param)
@@ -94,15 +90,12 @@ class CallStackElem(object):
 			else:
 				# This is a call to an FC.
 				# Prepare the interface (IN/OUT/INOUT) references.
-				# self.interfRefs is a dict of AwlIndirectOps for the FC interface.
+				# self.interfRefs is a dict of AwlOperators for the FC interface.
 				#                 The key of self.interfRefs is the interface field index.
 				#                 This dict is used by the CPU for lookup and resolve of
 				#                 the FC interface r-value.
 				self.interfRefs = {}
 				for param in parameters:
-					#TODO param interface assignment should
-					#     be done at translation time.
-					param.interface = blockInterface
 					try:
 						trans = self.__paramTrans[param.rvalueOp.type]
 					except KeyError as e:
@@ -123,16 +116,16 @@ class CallStackElem(object):
 		# Allocate space in the caller-L-stack.
 		lalloc = self.cpu.callStackTop.lalloc
 		loffset = lalloc.alloc(rvalueOp.width)
-		if param.isInbound:
-			# Write the value to the allocated space.
-			WordPacker.toBytes(lalloc.localdata, rvalueOp.width,
-					   loffset.byteOffset,
-					   self.cpu.fetch(rvalueOp))
 		# Make an operator for the allocated space.
-		oper = AwlOperator(AwlOperator.MEM_VL,
+		oper = AwlOperator(AwlOperator.MEM_L,
 				   rvalueOp.width,
 				   loffset,
 				   rvalueOp.insn)
+		if param.isInbound:
+			# Write the value to the allocated space.
+			self.cpu.store(oper, self.cpu.fetch(rvalueOp))
+		# Change the operator to VL
+		oper.type = oper.MEM_VL
 		# If outbound, save param and operator for return from CALL.
 		if param.isOutbound:
 			param.scratchSpaceOp = oper
