@@ -26,19 +26,23 @@ import time
 import datetime
 import random
 
+#from awlsim.core.cpu cimport * #@cy
+#from awlsim.core.dynattrs cimport * #@cy
+#from awlsim.core.statusword cimport * #@cy
+#from awlsim.core.instructions.all_insns cimport * #@cy
+
 from awlsim.core.cpuspecs import *
 from awlsim.core.parser import *
 from awlsim.core.symbolparser import *
 from awlsim.core.datatypes import *
-from awlsim.core.instructions.all_insns import *
+from awlsim.core.instructions.all_insns import * #@nocy
 from awlsim.core.systemblocks.system_sfb import *
 from awlsim.core.systemblocks.system_sfc import *
 from awlsim.core.operators import *
-from awlsim.core.insntrans import *
-from awlsim.core.optrans import *
+from awlsim.core.translator import *
 from awlsim.core.blocks import *
 from awlsim.core.datablocks import *
-from awlsim.core.statusword import *
+from awlsim.core.statusword import * #@nocy
 from awlsim.core.labels import *
 from awlsim.core.timers import *
 from awlsim.core.counters import *
@@ -78,11 +82,10 @@ class McrStackElem(object):
 
 	__nonzero__ = __bool__
 
-class S7CPU(object):
+class S7CPU(object): #+cdef
 	"STEP 7 CPU"
 
-	def __init__(self, sim):
-		self.sim = sim
+	def __init__(self):
 		self.specs = S7CPUSpecs(self)
 		self.setCycleTimeLimit(5.0)
 		self.setCycleExitCallback(None)
@@ -156,318 +159,98 @@ class S7CPU(object):
 					"Force mnemonics to EN or DE to avoid this error.")
 		specs.setDetectedMnemonics(detected)
 
-	def __translateInsn(self, rawInsn, ip):
-		ex = None
-		try:
-			insn = AwlInsnTranslator.fromRawInsn(self, rawInsn)
-			insn.setIP(ip)
-		except AwlSimError as e:
-			if e.getRawInsn() is None:
-				e.setRawInsn(rawInsn)
-			raise e
-		return insn
+	# Returns all user defined code blocks (OBs, FBs, FCs)
+	def __allUserCodeBlocks(self):
+		for ob in self.obs.values():
+			yield ob
+		for fb in self.fbs.values():
+			yield fb
+		for fc in self.fcs.values():
+			yield fc
 
-	def __translateInsns(self, rawInsns):
-		insns = []
-		# Translate raw instructions to simulator instructions
-		for ip, rawInsn in enumerate(rawInsns):
-			insns.append(self.__translateInsn(rawInsn, ip))
-		# If the last instruction is not BE or BEA, add an implicit BE
-		if not insns or insns[-1].type not in (AwlInsn.TYPE_BE,
-						       AwlInsn.TYPE_BEA):
-			insns.append(AwlInsn_BE(cpu = self, rawInsn = None))
-		return insns
+	# Returns all system code blocks (SFBs, SFCs)
+	def __allSystemCodeBlocks(self):
+		for sfb in self.sfbs.values():
+			yield sfb
+		for sfc in self.sfcs.values():
+			yield sfc
 
-	def __translateInterfaceField(self, rawVar):
-		dtype = AwlDataType.makeByName(rawVar.typeTokens, rawVar.dimensions)
-		assert(len(rawVar.idents) == 1) #TODO no structs, yet
-		field = BlockInterfaceField(name = rawVar.idents[0].name,
-					    dataType = dtype)
-		return field
+	# Returns all user defined code blocks (OBs, FBs, FCs, SFBs, SFCs)
+	def __allCodeBlocks(self):
+		for block in self.__allUserCodeBlocks():
+			yield block
+		for block in self.__allSystemCodeBlocks():
+			yield block
 
-	def __translateCodeBlock(self, rawBlock, blockClass):
-		insns = self.__translateInsns(rawBlock.insns)
-		block = blockClass(insns, rawBlock.index)
-		for rawVar in rawBlock.vars_in:
-			block.interface.addField_IN(self.__translateInterfaceField(rawVar))
-		for rawVar in rawBlock.vars_out:
-			block.interface.addField_OUT(self.__translateInterfaceField(rawVar))
-		if rawBlock.retTypeTokens:
-			# ARRAY is not supported for RET_VAL. So make non-array dtype.
-			dtype = AwlDataType.makeByName(rawBlock.retTypeTokens)
-			if dtype.type != AwlDataType.TYPE_VOID:
-				# Ok, we have a RET_VAL.
-				field = BlockInterfaceField(name = "RET_VAL",
-							    dataType = dtype)
-				block.interface.addField_OUT(field)
-		for rawVar in rawBlock.vars_inout:
-			block.interface.addField_INOUT(self.__translateInterfaceField(rawVar))
-		for rawVar in rawBlock.vars_static:
-			block.interface.addField_STAT(self.__translateInterfaceField(rawVar))
-		for rawVar in rawBlock.vars_temp:
-			block.interface.addField_TEMP(self.__translateInterfaceField(rawVar))
-		block.interface.buildDataStructure()
-		return block
-
-	# Initialize a DB (global or instance) data field from a raw data-init.
-	def __initDBField(self, db, dataType, rawDataInit):
-		if dataType.type == AwlDataType.TYPE_ARRAY:
-			index = dataType.arrayIndicesCollapse(*rawDataInit.idents[-1].indices)
-		else:
-			index = None
-		value = dataType.parseMatchingImmediate(rawDataInit.valueTokens)
-		db.structInstance.setFieldDataByName(rawDataInit.idents[-1].name,
-						     index, value)
-
-	def __translateGlobalDB(self, rawDB):
-		db = DB(rawDB.index, None)
-		# Create the data structure fields
-		for field in rawDB.fields:
-			assert(len(field.idents) == 1) #TODO no structs, yet
-			if not rawDB.getFieldInit(field):
-				raise AwlSimError(
-					"DB %d declares field '%s', "
-					"but does not initialize." %\
-					(rawDB.index, field.idents[0].name))
-			dtype = AwlDataType.makeByName(field.typeTokens,
-						       field.dimensions)
-			db.struct.addFieldNaturallyAligned(field.idents[0].name,
-							   dtype)
-		# Allocate the data structure fields
-		db.allocate()
-		# Initialize the data structure fields
-		for field, init in rawDB.allFieldInits():
-			if not field:
-				raise AwlSimError(
-					"DB %d assigns field '%s', "
-					"but does not declare it." %\
-					(rawDB.index, init.getIdentString()))
-			assert(len(field.idents) == 1 and len(init.idents) == 1) #TODO no structs, yet
-			dtype = AwlDataType.makeByName(field.typeTokens,
-						       field.dimensions)
-			self.__initDBField(db, dtype, init)
-		return db
-
-	def __translateInstanceDB(self, rawDB):
-		if rawDB.fb.fbSymbol is None:
-			fbStr = "SFB" if rawDB.fb.isSFB else "FB"
-			fbNumber = rawDB.fb.fbNumber
-			isSFB = rawDB.fb.isSFB
-		else:
-			fbStr = '"%s"' % rawDB.fb.fbSymbol
-			fbNumber, sym = self.__resolveBlockName((AwlDataType.TYPE_FB_X,
-								 AwlDataType.TYPE_SFB_X),
-								rawDB.fb.fbSymbol)
-			isSFB = sym.type.type == AwlDataType.TYPE_SFB_X
-
-		try:
-			if isSFB:
-				fb = self.sfbs[fbNumber]
-			else:
-				fb = self.fbs[fbNumber]
-		except KeyError:
-			raise AwlSimError("Instance DB %d references %s %d, "
-				"but %s %d does not exist." %\
-				(rawDB.index,
-				 fbStr, fbNumber,
-				 fbStr, fbNumber))
-		db = DB(rawDB.index, fb)
-		interface = fb.interface
-		# Sanity checks
-		if rawDB.fields:
-			raise AwlSimError("DB %d is an "
-				"instance DB, but it also "
-				"declares a data structure." %\
-				rawDB.index)
-		# Allocate the data structure fields
-		db.allocate()
-		# Initialize the data structure fields
-		for init in rawDB.fieldInits:
-			assert(len(init.idents) == 1) #TODO no structs, yet
-			dtype = interface.getFieldByName(init.idents[-1].name).dataType
-			self.__initDBField(db, dtype, init)
-		return db
-
-	def __translateDB(self, rawDB):
-		if rawDB.index < 0:
-			raise AwlSimError("DB number %d is invalid" % rawDB.index)
-		if rawDB.isInstanceDB():
-			return self.__translateInstanceDB(rawDB)
-		return self.__translateGlobalDB(rawDB)
-
-	# Translate classic symbols ("abc")
-	def __resolveClassicSym(self, block, insn, oper):
-		if oper.type == AwlOperator.SYMBOLIC:
-			symbol = self.symbolTable.findOneByName(oper.value.varName)
-			if not symbol:
-				raise AwlSimError("Symbol \"%s\" not found in "
-					"symbol table." % oper.value.varName,
-					insn = insn)
-			newOper = symbol.operator.dup()
-			newOper.setInsn(oper.insn)
-			return newOper
-		return oper
-
-	# Translate symbolic OB/FB/FC/DB block name
-	def __resolveBlockName(self, blockTypeIds, blockName):
-		if isString(blockName):
-			symbol = self.symbolTable.findOneByName(blockName)
-			if not symbol:
-				raise AwlSimError("Symbolic block name \"%s\" "
-					"not found in symbol table." % blockName)
-			if symbol.type.type not in blockTypeIds:
-				raise AwlSimError("Symbolic block name \"%s\" "
-					"has an invalid type." % blockName)
-			return symbol.operator.value.byteOffset, symbol
-		return blockName, None
-
-	# Translate local symbols (#abc or P##abc)
-	# If pointer is false, try to resolve #abc.
-	# If pointer is true, try to resolve P##abc.
-	def resolveNamedLocal(self, block, insn, oper, pointer=False):
-		if pointer:
-			if oper.type != AwlOperator.NAMED_LOCAL_PTR:
-				return oper
-		else:
-			if oper.type != AwlOperator.NAMED_LOCAL:
-				return oper
-
-		# Get the interface field for this variable
-		field = block.interface.getFieldByName(oper.value.varName)
-
-		# Sanity checks
-		if field.dataType.type == AwlDataType.TYPE_ARRAY:
-			if not oper.value.indices and\
-			   oper.type != AwlOperator.NAMED_LOCAL_PTR:
-				raise AwlSimError("Cannot address array #%s "
-					"without subscript list." %\
-					oper.value.varName)
-		else:
-			if oper.value.indices:
-				raise AwlSimError("Trying to subscript array, "
-					"but #%s is not an array." %\
-					oper.value.varName)
-
-		if block.interface.hasInstanceDB or\
-		   field.fieldType == BlockInterfaceField.FTYPE_TEMP:
-			# This is an FB or a TEMP access. Translate the operator
-			# to a DI/TEMP access.
-			newOper = block.interface.getOperatorForField(oper.value.varName,
-								      oper.value.indices,
-								      pointer)
-			newOper.setInsn(oper.insn)
-			return newOper
-		else:
-			# This is an FC. Accesses to local symbols
-			# are resolved at runtime.
-			# Just set the value to the interface index.
-			#TODO array
-			index = block.interface.getFieldIndex(oper.value.varName)
-			oper.interfaceIndex = index
-		return oper
-
-	# Translate named fully qualified accesses (DBx.VARx)
-	def __resolveNamedFullyQualified(self, block, insn, oper):
-		if oper.type != AwlOperator.NAMED_DBVAR:
-			return oper
-
-		# Resolve the symbolic DB name, if needed
-		assert(oper.value.dbNumber is not None or\
-		       oper.value.dbName is not None)
-		if oper.value.dbNumber is None:
-			symbol = self.symbolTable.findOneByName(oper.value.dbName)
-			if not symbol:
-				raise AwlSimError("Symbol \"%s\" specified as DB in "
-					"fully qualified operator not found." %\
-					oper.value.dbName)
-			if symbol.type.type != AwlDataType.TYPE_DB_X:
-				raise AwlSimError("Symbol \"%s\" specified as DB in "
-					"fully qualified operator is not a DB-symbol." %\
-					oper.value.dbName)
-			oper.value.dbNumber = symbol.operator.value.byteOffset
-
-		# Get the DB
-		try:
-			db = self.dbs[oper.value.dbNumber]
-		except KeyError as e:
-			raise AwlSimError("DB %d specified in fully qualified "
-				"operator does not exist." % oper.value.dbNumber)
-
-		# Get the data structure field descriptor
-		# and construct the AwlOffset.
-		field = db.struct.getField(oper.value.varName)
-		if oper.value.indices is None:
-			# Non-array access.
-			if field.dataType.type == AwlDataType.TYPE_ARRAY:
-				#TODO this happens for parameter passing
-				raise AwlSimError("Variable '%s' in fully qualified "
-					"DB access is an ARRAY." %\
-					oper.value.varName)
-		else:
-			# This is an array access.
-			if field.dataType.type != AwlDataType.TYPE_ARRAY:
-				raise AwlSimError("Indexed variable '%s' in fully qualified "
-					"DB access is not an ARRAY." %\
-					oper.value.varName)
-			index = field.dataType.arrayIndicesCollapse(*oper.value.indices)
-			# Get the actual data field
-			field = db.struct.getField(oper.value.varName, index)
-		# Extract the offset data
-		offset = field.offset.dup()
-		width = field.bitSize
-		offset.dbNumber = oper.value.dbNumber
-
-		# Construct an absolute operator
-		return AwlOperator(type = AwlOperator.MEM_DB,
-				   width = width,
-				   value = offset,
-				   insn = oper.insn)
-
-	def __resolveSymbols_block(self, block):
+	def __allCallInsns(self, block):
 		for insn in block.insns:
+			if insn.insnType != AwlInsn.TYPE_CALL:
+				continue
+
+			# Get the code and DB blocks
+			try:
+				if len(insn.ops) == 1:
+					dataBlock = None
+				elif len(insn.ops) == 2:
+					dataBlockOp = insn.ops[1]
+					if dataBlockOp.type != AwlOperator.BLKREF_DB:
+						raise ValueError
+					dataBlock = self.dbs[dataBlockOp.value.byteOffset]
+				else:
+					assert(0)
+				codeBlockOp = insn.ops[0]
+				if codeBlockOp.type == AwlOperator.BLKREF_FC:
+					codeBlock = self.fcs[codeBlockOp.value.byteOffset]
+				elif codeBlockOp.type == AwlOperator.BLKREF_FB:
+					codeBlock = self.fbs[codeBlockOp.value.byteOffset]
+				elif codeBlockOp.type == AwlOperator.BLKREF_SFC:
+					codeBlock = self.sfcs[codeBlockOp.value.byteOffset]
+				elif codeBlockOp.type == AwlOperator.BLKREF_SFB:
+					codeBlock = self.sfbs[codeBlockOp.value.byteOffset]
+				else:
+					raise ValueError
+			except (KeyError, ValueError) as e:
+				# This error is handled later in call-insn sanity checks
+				continue
+
+			yield insn, codeBlock, dataBlock
+
+	def __checkCallParamTypeCompat(self, block):
+		for insn, calledCodeBlock, calledDataBlock in self.__allCallInsns(block):
 			try:
-				for i, oper in enumerate(insn.ops):
-					oper = self.__resolveClassicSym(block, insn, oper)
-					oper = self.resolveNamedLocal(block, insn, oper, False)
-					oper = self.__resolveNamedFullyQualified(block, insn, oper)
-					if oper.type == AwlOperator.INDIRECT:
-						oper.offsetOper = self.__resolveClassicSym(block,
-									insn, oper.offsetOper)
-						oper.offsetOper = self.resolveNamedLocal(block,
-									insn, oper.offsetOper, False)
-					oper = self.resolveNamedLocal(block, insn, oper, True)
-					insn.ops[i] = oper
 				for param in insn.params:
-					oper = param.rvalueOp
-					oper = self.__resolveClassicSym(block, insn, oper)
-					oper = self.resolveNamedLocal(block, insn, oper, False)
-					oper = self.__resolveNamedFullyQualified(block, insn, oper)
-					if oper.type == AwlOperator.INDIRECT:
-						oper.offsetOper = self.__resolveClassicSym(block,
-									insn, oper.offsetOper)
-						oper.offsetOper = self.resolveNamedLocal(block,
-									insn, oper.offsetOper, False)
-					oper = self.resolveNamedLocal(block, insn, oper, False)
-					param.rvalueOp = oper
+					# Get the interface field for this variable
+					field = calledCodeBlock.interface.getFieldByName(param.lvalueName)
+					# Check type compatibility
+					param.rvalueOp.checkDataTypeCompat(field.dataType)
 			except AwlSimError as e:
-				if not e.getInsn():
-					e.setInsn(insn)
+				e.setInsn(insn)
 				raise e
 
+	def __finalizeCodeBlock(self, block):
+		# Finalize call instructions
+		for insn, calledCodeBlock, calledDataBlock in self.__allCallInsns(block):
+			# Add interface references to the parameter assignments.
+			for param in insn.params:
+				param.interface = calledCodeBlock.interface
+				param.instanceDB = calledDataBlock
+
+	def __finalizeCodeBlocks(self):
+		for block in self.__allUserCodeBlocks():
+			self.__finalizeCodeBlock(block)
+
 	# Resolve all symbols (global and local) on all blocks, as far as possible.
 	def __resolveSymbols(self):
-		for ob in self.obs.values():
-			self.__resolveSymbols_block(ob)
-		for fb in self.fbs.values():
-			self.__resolveSymbols_block(fb)
-		for fc in self.fcs.values():
-			self.__resolveSymbols_block(fc)
-		for sfc in self.sfcs.values():
-			self.__resolveSymbols_block(sfc)
-			sfc.resolveHardwiredSymbols()
-		for sfb in self.sfbs.values():
-			self.__resolveSymbols_block(sfb)
-			sfb.resolveHardwiredSymbols()
+		resolver = AwlSymResolver(self)
+		for block in self.__allCodeBlocks():
+			# Check type compatibility between formal and
+			# actual parameter of calls.
+			self.__checkCallParamTypeCompat(block)
+			# Resolve all symbols
+			resolver.resolveSymbols_block(block)
+			# Check type compatibility between formal and
+			# actual parameter of calls again, with resolved symbols.
+			self.__checkCallParamTypeCompat(block)
 
 	# Run static error checks for code block
 	def __staticSanityChecks_block(self, block):
@@ -481,25 +264,24 @@ class S7CPU(object):
 		except KeyError:
 			raise AwlSimError("No OB1 defined")
 
-		for ob in self.obs.values():
-			self.__staticSanityChecks_block(ob)
-		for fb in self.fbs.values():
-			self.__staticSanityChecks_block(fb)
-		for fc in self.fcs.values():
-			self.__staticSanityChecks_block(fc)
+		for block in self.__allUserCodeBlocks():
+			self.__staticSanityChecks_block(block)
 
 	def load(self, parseTree):
+		translator = AwlTranslator(self)
+		resolver = AwlSymResolver(self)
+
 		# Mnemonics autodetection
 		self.__detectMnemonics(parseTree)
 		# Translate OBs
 		for obNumber, rawOB in parseTree.obs.items():
-			obNumber, sym = self.__resolveBlockName((AwlDataType.TYPE_OB_X,),
-								obNumber)
+			obNumber, sym = resolver.resolveBlockName((AwlDataType.TYPE_OB_X,),
+								  obNumber)
 			if obNumber in self.obs:
 				raise AwlSimError("Multiple definitions of "\
 					"OB %d" % obNumber)
 			rawOB.index = obNumber
-			ob = self.__translateCodeBlock(rawOB, OB)
+			ob = translator.translateCodeBlock(rawOB, OB)
 			self.obs[obNumber] = ob
 			# Create the TEMP-preset handler table
 			try:
@@ -509,23 +291,23 @@ class S7CPU(object):
 			self.obTempPresetHandlers[obNumber] = presetHandlerClass(self)
 		# Translate FBs
 		for fbNumber, rawFB in parseTree.fbs.items():
-			fbNumber, sym = self.__resolveBlockName((AwlDataType.TYPE_FB_X,),
-								fbNumber)
+			fbNumber, sym = resolver.resolveBlockName((AwlDataType.TYPE_FB_X,),
+								  fbNumber)
 			if fbNumber in self.fbs:
 				raise AwlSimError("Multiple definitions of "\
 					"FB %d" % fbNumber)
 			rawFB.index = fbNumber
-			fb = self.__translateCodeBlock(rawFB, FB)
+			fb = translator.translateCodeBlock(rawFB, FB)
 			self.fbs[fbNumber] = fb
 		# Translate FCs
 		for fcNumber, rawFC in parseTree.fcs.items():
-			fcNumber, sym = self.__resolveBlockName((AwlDataType.TYPE_FC_X,),
-								fcNumber)
+			fcNumber, sym = resolver.resolveBlockName((AwlDataType.TYPE_FC_X,),
+								  fcNumber)
 			if fcNumber in self.fcs:
 				raise AwlSimError("Multiple definitions of "\
 					"FC %d" % fcNumber)
 			rawFC.index = fcNumber
-			fc = self.__translateCodeBlock(rawFC, FC)
+			fc = translator.translateCodeBlock(rawFC, FC)
 			self.fcs[fcNumber] = fc
 
 		if not self.sfbs:
@@ -547,15 +329,15 @@ class S7CPU(object):
 
 		# Translate DBs
 		for dbNumber, rawDB in parseTree.dbs.items():
-			dbNumber, sym = self.__resolveBlockName((AwlDataType.TYPE_DB_X,
-								 AwlDataType.TYPE_FB_X,
-								 AwlDataType.TYPE_SFB_X),
-								dbNumber)
+			dbNumber, sym = resolver.resolveBlockName((AwlDataType.TYPE_DB_X,
+								   AwlDataType.TYPE_FB_X,
+								   AwlDataType.TYPE_SFB_X),
+								  dbNumber)
 			if dbNumber in self.dbs:
 				raise AwlSimError("Multiple definitions of "\
 					"DB %d" % dbNumber)
 			rawDB.index = dbNumber
-			db = self.__translateDB(rawDB)
+			db = translator.translateDB(rawDB)
 			self.dbs[dbNumber] = db
 
 	def loadSymbolTable(self, symbolTable):
@@ -704,6 +486,8 @@ class S7CPU(object):
 	def startup(self):
 		# Resolve symbolic instructions and operators
 		self.__resolveSymbols()
+		# Do some finalizations
+		self.__finalizeCodeBlocks()
 		# Run some static sanity checks on the code
 		self.__staticSanityChecks()
 
@@ -1039,7 +823,8 @@ class S7CPU(object):
 	def storeInputRange(self, byteOffset, data):
 		self.inputs[byteOffset : byteOffset + len(data)] = data
 
-	def fetch(self, operator, enforceWidth=()):
+	def fetch(self, operator, enforceWidth=()): #@nocy
+#@cy	cpdef object fetch(self, object operator, tuple enforceWidth=()):
 		try:
 			fetchMethod = self.fetchTypeMethods[operator.type]
 		except KeyError:
@@ -1219,7 +1004,7 @@ class S7CPU(object):
 		return self.inputs.fetch(operator.value, operator.width)
 
 	def fetchT(self, operator, enforceWidth):
-		insnType = operator.insn.type
+		insnType = operator.insn.insnType
 		if insnType == AwlInsn.TYPE_L or insnType == AwlInsn.TYPE_LC:
 			width = 32
 		else:
@@ -1235,7 +1020,7 @@ class S7CPU(object):
 		return timer.get()
 
 	def fetchZ(self, operator, enforceWidth):
-		insnType = operator.insn.type
+		insnType = operator.insn.insnType
 		if insnType == AwlInsn.TYPE_L or insnType == AwlInsn.TYPE_LC:
 			width = 32
 		else:
@@ -1252,10 +1037,16 @@ class S7CPU(object):
 
 	def fetchNAMED_LOCAL(self, operator, enforceWidth):
 		# load from an FC interface field.
-		return self.fetch(self.callStackTop.interfRefs[operator.interfaceIndex].resolve(False),
-				  enforceWidth)
+		# First get the translated rvalue-operand that was used in the call.
+		translatedOp = self.callStackTop.interfRefs[operator.interfaceIndex].resolve(False)
+		# Add possible sub-offsets (array, struct) to the offset.
+		finalOp = translatedOp.dup()
+		finalOp.value += operator.value.subOffset
+		finalOp.width = operator.width
+		return self.fetch(finalOp, enforceWidth)
 
 	def fetchNAMED_LOCAL_PTR(self, operator, enforceWidth):
+		assert(operator.value.subOffset.byteOffset == 0)
 		return self.callStackTop.interfRefs[operator.interfaceIndex].resolve(False).makePointer()
 
 	def fetchNAMED_DBVAR(self, operator, enforceWidth):
@@ -1335,7 +1126,8 @@ class S7CPU(object):
 		AwlOperator.VIRT_DBR		: fetchVirtDBR,
 	}
 
-	def store(self, operator, value, enforceWidth=()):
+	def store(self, operator, value, enforceWidth=()): #@nocy
+#@cy	cpdef store(self, object operator, object value, tuple enforceWidth=()):
 		try:
 			storeMethod = self.storeTypeMethods[operator.type]
 		except KeyError:
@@ -1446,8 +1238,13 @@ class S7CPU(object):
 
 	def storeNAMED_LOCAL(self, operator, value, enforceWidth):
 		# store to an FC interface field.
-		self.store(self.callStackTop.interfRefs[operator.interfaceIndex].resolve(True),
-			   value, enforceWidth)
+		# First get the translated rvalue-operand that was used in the call.
+		translatedOp = self.callStackTop.interfRefs[operator.interfaceIndex].resolve(True)
+		# Add possible sub-offsets (array, struct) to the offset.
+		finalOp = translatedOp.dup()
+		finalOp.value += operator.value.subOffset
+		finalOp.width = operator.width
+		self.store(finalOp, value, enforceWidth)
 
 	def storeNAMED_DBVAR(self, operator, value, enforceWidth):
 		# All legit accesses will have been translated to absolute addressing already
