@@ -22,13 +22,15 @@
 from __future__ import division, absolute_import, print_function, unicode_literals
 from awlsim.core.compat import *
 
-from awlsim.core.dynattrs import *
+#from awlsim.core.dynattrs cimport * #@cy
+
+from awlsim.core.dynattrs import * #@nocy
 from awlsim.core.util import *
 from awlsim.core.timers import *
 from awlsim.core.datatypehelpers import *
 
 
-class AwlOffset(DynAttrs):
+class AwlOffset(DynAttrs): #+cdef
 	"Memory area offset"
 
 	dynAttrs = {
@@ -43,6 +45,11 @@ class AwlOffset(DynAttrs):
 
 		# List of Variable indices for fully qualified array access, or None.
 		"indices"	: None,
+
+		# Additional sub-offset that is added to this offset.
+		# Defaults to 0.0
+		# This is used for arrays and structs.
+		"subOffset"	: lambda self, name: AwlOffset(0, 0),
 	}
 
 	def __init__(self, byteOffset, bitOffset=0):
@@ -64,6 +71,18 @@ class AwlOffset(DynAttrs):
 		return ((self.byteOffset << 3) & 0x0007FFF8) |\
 		       (self.bitOffset & 0x7)
 
+	def __add__(self, other):
+		bitOffset = (self.byteOffset + other.byteOffset) * 8 +\
+			    self.bitOffset + other.bitOffset
+		return AwlOffset(bitOffset // 8, bitOffset % 8)
+
+	def __iadd__(self, other):
+		bitOffset = (self.byteOffset + other.byteOffset) * 8 +\
+			    self.bitOffset + other.bitOffset
+		self.byteOffset = bitOffset // 8
+		self.bitOffset = bitOffset % 8
+		return self
+
 	def __repr__(self):
 		prefix = ""
 		if self.dbNumber is not None:
@@ -239,7 +258,7 @@ class AwlDataType(object):
 			# Each element is a ref to the same AwlDataType instance.
 			children = tuple([ elementType, ] * nrArrayElements)
 			return cls(type = cls.TYPE_ARRAY,
-				   width = nrArrayElements,
+				   width = nrArrayElements * elementType.width,
 				   isSigned = (type in cls.signedTypes),
 				   index = index,
 				   children = children,
@@ -254,16 +273,18 @@ class AwlDataType(object):
 		     index=None, children=None,
 		     arrayDimensions=None):
 		self.type = type		# The TYPE_... for this datatype
-		self.width = width		# The width, in bits. If type==TYPE_ARRAY, this is the number of elements.
+		self.width = width		# The width, in bits.
 		self.isSigned = isSigned	# True, if this type is signed
 		self.index = index		# The Index number, if any. May be None
 		self.children = children	# The children AwlDataTypes, if ARRAY.
 		self.arrayDimensions = arrayDimensions # The ARRAY's dimensions
 
 	# Convert array indices into a one dimensional index for this array.
-	# 'indices' are the indices as written in the AWL operator
+	# 'indices' is a list of index integers as written in the AWL operator
 	# from left to right.
-	def arrayIndicesCollapse(self, *indices):
+	def arrayIndicesCollapse(self, indices):
+		if not indices:
+			return None
 		if len(indices) < 1 or len(indices) > 6:
 			raise AwlSimError("Invalid number of array indices")
 		assert(self.type == self.TYPE_ARRAY)
@@ -272,7 +293,11 @@ class AwlDataType(object):
 		assert(len(indices) == len(self.arrayDimensions))
 		resIndex = 0
 		for i, idx in enumerate(indices):
-			startIdx = self.arrayDimensions[i][0]
+			startIdx, endIdx = self.arrayDimensions[i]
+			if idx < startIdx or idx > endIdx:
+				raise AwlSimError("Array index '%d' is out of bounds "
+					"for array range '%d .. %d'." %\
+					(idx, startIdx, endIdx))
 			resIndex += (idx - startIdx) * signif[i]
 		return resIndex
 
@@ -291,6 +316,11 @@ class AwlDataType(object):
 			signif.append(size * signif[-1])
 		return tuple(signif[::-1])
 
+	# Get the number of array elements
+	def arrayGetNrElements(self):
+		assert(self.type == self.TYPE_ARRAY)
+		return len(self.children)
+
 	# Parse an immediate, constrained by our datatype.
 	def parseMatchingImmediate(self, tokens):
 		typeId = self.type
@@ -467,6 +497,8 @@ class AwlDataType(object):
 	def __parseGenericTime(cls, token):
 		# Parse T# or S5T# time formats.
 		# The prefix is already stripped.
+		if not token:
+			raise AwlSimError("Invalid time")
 		token = token.upper()
 		p = token
 		seconds = 0.0
@@ -501,7 +533,7 @@ class AwlDataType(object):
 		return seconds
 
 	@classmethod
-	def formatTime(cls, seconds):
+	def formatTime(cls, seconds, leadingZeros=False):
 		# Format a seconds value into time format.
 		d = int(seconds // 86400)
 		seconds -= d * 86400
@@ -513,8 +545,14 @@ class AwlDataType(object):
 		seconds -= s
 		ms = int(seconds * 1000.0)
 		ret = []
-		for v, b in ((d, "d"), (h, "h"), (m, "m"), (s, "s"), (ms, "ms")):
-			if v:
+		for v, b, d in ((d, "d", 1), (h, "h", 2), (m, "m", 2),
+				(s, "s", 2), (ms, "ms", 3)):
+			if not v:
+				continue
+			if leadingZeros:
+				fmt = "%0" + str(d) + "d%s"
+				ret.append(fmt % (v, b))
+			else:
 				ret.append("%d%s" % (v, b))
 		if not ret:
 			return "0ms"
@@ -734,71 +772,97 @@ class AwlDataType(object):
 			raise AwlSimError("Invalid immediate")
 		return immediate
 
-class GenericInteger(object):
-	def __init__(self, value, width):
+class GenericInteger(object): #+cdef
+
+#@cy	cdef public uint32_t value
+#@cy	cdef public uint32_t mask
+
+	def __init__(self, value, width): #@nocy
+#@cy	def __init__(self, int64_t value, uint8_t width):
+#@cy		cdef uint64_t one
+
 		assert(width > 0 and width <= 32)
 		self.value = value
-		self.mask = int(((1 << width) - 1) & 0xFFFFFFFF)
+		one = 1
+		self.mask = int(((one << width) - 1) & 0xFFFFFFFF)
 
-	def copyFrom(self, other):
+	def copyFrom(self, other): #@nocy
+#@cy	cpdef copyFrom(self, GenericInteger other):
 		self.value = other.value & self.mask
 
-	def set(self, value):
+	def set(self, value): #@nocy
+#@cy	cpdef set(self, int64_t value):
 		self.value = value & self.mask
 
-	def setByte(self, value):
+	def setByte(self, value): #@nocy
+#@cy	cpdef setByte(self, int64_t value):
 		self.value = ((self.value & 0xFFFFFF00) |\
 			      (value & 0xFF)) &\
 			     self.mask
 
-	def setWord(self, value):
+	def setWord(self, value): #@nocy
+#@cy	cpdef setWord(self, int64_t value):
 		self.value = ((self.value & 0xFFFF0000) |\
 			      (value & 0xFFFF)) &\
 			     self.mask
 
-	def setDWord(self, value):
+	def setDWord(self, value): #@nocy
+#@cy	cpdef setDWord(self, int64_t value):
 		self.value = value & 0xFFFFFFFF & self.mask
 
-	def setPyFloat(self, pyfl):
+	def setPyFloat(self, pyfl): #@nocy
+#@cy	cpdef setPyFloat(self, pyfl):
 		self.value = pyFloatToDWord(pyfl)
 
-	def get(self):
+	def get(self): #@nocy
+#@cy	cpdef uint32_t get(self):
 		return self.value
 
-	def getByte(self):
+	def getByte(self): #@nocy
+#@cy	cpdef uint8_t getByte(self):
 		return self.value & 0xFF
 
-	def getWord(self):
+	def getWord(self): #@nocy
+#@cy	cpdef uint16_t getWord(self):
 		return self.value & 0xFFFF
 
-	def getDWord(self):
+	def getDWord(self): #@nocy
+#@cy	cpdef uint32_t getDWord(self):
 		return self.value & 0xFFFFFFFF
 
-	def getSignedByte(self):
+	def getSignedByte(self): #@nocy
+#@cy	cpdef int8_t getSignedByte(self):
 		return byteToSignedPyInt(self.value)
 
-	def getSignedWord(self):
+	def getSignedWord(self): #@nocy
+#@cy	cpdef int16_t getSignedWord(self):
 		return wordToSignedPyInt(self.value)
 
-	def getSignedDWord(self):
+	def getSignedDWord(self): #@nocy
+#@cy	cpdef int32_t getSignedDWord(self):
 		return dwordToSignedPyInt(self.value)
 
-	def getPyFloat(self):
+	def getPyFloat(self): #@nocy
+#@cy	cpdef getPyFloat(self):
 		return dwordToPyFloat(self.value)
 
-	def setBit(self, bitNumber):
+	def setBit(self, bitNumber): #@nocy
+#@cy	cpdef setBit(self, uint8_t bitNumber):
 		self.value = (self.value | (1 << bitNumber)) & self.mask
 
-	def clearBit(self, bitNumber):
+	def clearBit(self, bitNumber): #@nocy
+#@cy	cpdef clearBit(self, uint8_t bitNumber):
 		self.value &= ~(1 << bitNumber)
 
-	def setBitValue(self, bitNumber, value):
+	def setBitValue(self, bitNumber, value): #@nocy
+#@cy	cpdef setBitValue(self, uint8_t bitNumber, uint8_t value):
 		if value:
 			self.setBit(bitNumber)
 		else:
 			self.clearBit(bitNumber)
 
-	def getBit(self, bitNumber):
+	def getBit(self, bitNumber): #@nocy
+#@cy	cpdef unsigned char getBit(self, uint8_t bitNumber):
 		return (self.value >> bitNumber) & 1
 
 	def toHex(self):
@@ -811,16 +875,19 @@ class GenericInteger(object):
 		else:
 			assert(0)
 
-class GenericWord(GenericInteger):
+class GenericWord(GenericInteger): #+cdef
 	def __init__(self, value=0):
 		GenericInteger.__init__(self, value, 16)
 
-class GenericDWord(GenericInteger):
+class GenericDWord(GenericInteger): #+cdef
 	def __init__(self, value=0):
 		GenericInteger.__init__(self, value, 32)
 
 class ByteArray(bytearray):
-	def fetch(self, offset, width):
+	def fetch(self, offset, width): #@nocy
+#@cy	def fetch(self, object offset, uint32_t width):
+#@cy		cdef uint32_t byteOffset
+
 		byteOffset = offset.byteOffset
 		try:
 			if width == 1:
@@ -835,11 +902,19 @@ class ByteArray(bytearray):
 				       (self[byteOffset + 1] << 16) |\
 				       (self[byteOffset + 2] << 8) |\
 				       self[byteOffset + 3]
+			else:
+				assert(not offset.bitOffset)
+				nrBytes = intDivRoundUp(width, 8)
+				if byteOffset + nrBytes > len(self):
+					raise IndexError
+				return memoryview(self)[byteOffset : byteOffset + nrBytes]
 		except IndexError as e:
 			raise AwlSimError("fetch: Operator offset out of range")
-		assert(0)
 
-	def store(self, offset, width, value):
+	def store(self, offset, width, value): #@nocy
+#@cy	def store(self, object offset, uint32_t width, object value):
+#@cy		cdef uint32_t byteOffset
+
 		byteOffset = offset.byteOffset
 		try:
 			if width == 1:
@@ -858,17 +933,22 @@ class ByteArray(bytearray):
 				self[byteOffset + 2] = (value >> 8) & 0xFF
 				self[byteOffset + 3] = value & 0xFF
 			else:
-				assert(0)
+				assert(not offset.bitOffset)
+				nrBytes = intDivRoundUp(width, 8)
+				assert(nrBytes == len(value))
+				if byteOffset + nrBytes > len(self):
+					raise IndexError
+				self[byteOffset : byteOffset + len(value)] = value
 		except IndexError as e:
 			raise AwlSimError("store: Operator offset out of range")
 
-class Accu(GenericDWord):
+class Accu(GenericDWord): #+cdef
 	"Accumulator register"
 
 	def __init__(self):
 		GenericDWord.__init__(self)
 
-class Adressregister(GenericDWord):
+class Adressregister(GenericDWord): #+cdef
 	"Address register"
 
 	def __init__(self):
