@@ -2,7 +2,7 @@
 #
 # AWL simulator - instructions
 #
-# Copyright 2012-2013 Michael Buesch <m@bues.ch>
+# Copyright 2012-2014 Michael Buesch <m@bues.ch>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,21 +22,23 @@
 from __future__ import division, absolute_import, print_function, unicode_literals
 from awlsim.core.compat import *
 
-from awlsim.core.instructions.main import *
+from awlsim.core.instructions.main import * #@nocy
+from awlsim.core.operators import *
+#from awlsim.core.instructions.main cimport * #@cy
 
 
-class AwlInsn_RRDA(AwlInsn):
+class AwlInsn_RRDA(AwlInsn): #+cdef
 	def __init__(self, cpu, rawInsn):
 		AwlInsn.__init__(self, cpu, AwlInsn.TYPE_RRDA, rawInsn)
 		self.assertOpCount(0)
 
 	def run(self):
+#@cy		cdef S7StatusWord s
+
 		s = self.cpu.statusWord
-		accu1, count = self.cpu.accu1.getDWord(), 1
-		s.A0, s.OV = 0, 0
-		accu1 &= 0xFFFFFFFF
-		accu1 |= (s.A1 & 1) << 32
-		accu1 = ((accu1 >> count) | (accu1 << (33 - count))) & 0x1FFFFFFFF
-		s.A1 = (accu1 >> 32) & 1
-		accu1 &= 0xFFFFFFFF
+		oldA1 = s.A1 & 1
+		accu1 = self.cpu.accu1.getDWord()
+		s.A0, s.A1, s.OV = 0, (accu1 & 1), 0
+		accu1 >>= 1
+		accu1 |= oldA1 << 31
 		self.cpu.accu1.set(accu1)
