@@ -2,7 +2,7 @@
 #
 # AWL simulator - instructions
 #
-# Copyright 2012-2013 Michael Buesch <m@bues.ch>
+# Copyright 2012-2014 Michael Buesch <m@bues.ch>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,25 +22,35 @@
 from __future__ import division, absolute_import, print_function, unicode_literals
 from awlsim.core.compat import *
 
-from awlsim.core.instructions.main import *
+from awlsim.core.instructions.main import * #@nocy
+from awlsim.core.operators import *
+#from awlsim.core.instructions.main cimport * #@cy
 
 import time
 
 
-class AwlInsn_SLEEP(AwlInsn):
+class AwlInsn_SLEEP(AwlInsn): #+cdef
 	def __init__(self, cpu, rawInsn):
 		AwlInsn.__init__(self, cpu, AwlInsn.TYPE_SLEEP, rawInsn)
 		self.assertOpCount(1)
 
 	def run(self):
-		msecs = self.cpu.fetch(self.ops[0])
+#@cy		cdef S7StatusWord s
 
-		if float(msecs) / 1000 >= self.cpu.cycleTimeLimit:
+		sleepMsecs = self.cpu.fetch(self.ops[0])
+		sleepSecs = sleepMsecs / 1000.0
+
+		if sleepSecs >= self.cpu.cycleTimeLimit:
 			raise AwlSimError("__SLEEP time exceed cycle time limit")
 
-		while msecs > 0:
-			m = min(50, msecs)
-			time.sleep(float(m) / 1000)
+		self.cpu.updateTimestamp()
+		start = self.cpu.now
+		while 1:
 			self.cpu.updateTimestamp()
-			self.cpu.requestScreenUpdate()
-			msecs -= m
+			slept = self.cpu.now - start
+			remaining = sleepSecs - slept
+			if remaining <= 0.0:
+				break
+			if remaining >= 0.1:
+				self.cpu.requestScreenUpdate()
+				time.sleep(0.05)
