@@ -2,7 +2,7 @@
 #
 # AWL simulator - instructions
 #
-# Copyright 2012-2013 Michael Buesch <m@bues.ch>
+# Copyright 2012-2014 Michael Buesch <m@bues.ch>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,10 +22,12 @@
 from __future__ import division, absolute_import, print_function, unicode_literals
 from awlsim.core.compat import *
 
-from awlsim.core.instructions.main import *
+from awlsim.core.instructions.main import * #@nocy
+from awlsim.core.operators import *
+#from awlsim.core.instructions.main cimport * #@cy
 
 
-class AwlInsn_SV(AwlInsn):
+class AwlInsn_SV(AwlInsn): #+cdef
 	def __init__(self, cpu, rawInsn):
 		AwlInsn.__init__(self, cpu, AwlInsn.TYPE_SV, rawInsn)
 		self.assertOpCount(1)
@@ -34,5 +36,7 @@ class AwlInsn_SV(AwlInsn):
 		self.ops[0].assertType(AwlOperator.MEM_T)
 
 	def run(self):
+#@cy		cdef S7StatusWord s
+
 		self.cpu.getTimer(self.ops[0].resolve(True).value.byteOffset
 			).run_SV(self.cpu.accu1.get())
