@@ -34,7 +34,7 @@ import importlib
 class AwlSim(object):
 	def __init__(self, profileLevel=0):
 		self.__registeredHardware = []
-		self.cpu = S7CPU(self)
+		self.cpu = S7CPU()
 		self.cpu.setPeripheralReadCallback(self.__peripheralReadCallback)
 		self.cpu.setPeripheralWriteCallback(self.__peripheralWriteCallback)
 
@@ -205,8 +205,16 @@ class AwlSim(object):
 		'name' is the name of the module to load (without 'awlsimhw_' prefix).
 		Returns the HardwareInterface class."""
 
+		import awlsim.cython_helper as cython_helper
+
 		# Construct the python module name
 		moduleName = "awlsimhw_%s" % name
+		if cython_helper.shouldUseCython():
+			cyModuleName = "awlsimhw_%s_cython" % name
+			printInfo("Awlsim-cython: Loading '%s' instead of '%s'" %\
+				  (cyModuleName, moduleName))
+			moduleName = cyModuleName
+
 		# Try to import the module
 		try:
 			mod = importlib.import_module(moduleName)
