@@ -200,10 +200,10 @@ class RawAwlDataField(object):
 
 class RawAwlDB(RawAwlBlock):
 	class FBRef(object):
-		def __init__(self, fbName, fbNumber, isSFB):
-			self.fbName = fbName
+		def __init__(self, fbNumber=None, isSFB=None, fbSymbol=None):
 			self.fbNumber = fbNumber
 			self.isSFB = isSFB
+			self.fbSymbol = fbSymbol
 
 	def __init__(self, tree, index):
 		RawAwlBlock.__init__(self, tree, index)
@@ -546,6 +546,9 @@ class AwlParser(object):
 					except ValueError:
 						raise AwlParserError("Invalid DB number")
 				self.tree.curBlock = RawAwlDB(self.tree, dbNumber)
+				if dbNumber in self.tree.dbs:
+					raise AwlParserError("Multiple definitions "
+						"of DB %s" % str(dbNumber))
 				self.tree.dbs[dbNumber] = self.tree.curBlock
 				return
 			if t.tokens[0].upper() == "FUNCTION_BLOCK":
@@ -563,6 +566,9 @@ class AwlParser(object):
 					except ValueError:
 						raise AwlParserError("Invalid FB number")
 				self.tree.curBlock = RawAwlFB(self.tree, fbNumber)
+				if fbNumber in self.tree.fbs:
+					raise AwlParserError("Multiple definitions "
+						"of FB %s" % str(fbNumber))
 				self.tree.fbs[fbNumber] = self.tree.curBlock
 				return
 			if t.tokens[0].upper() == "FUNCTION":
@@ -588,6 +594,9 @@ class AwlParser(object):
 					raise AwlParserError("Missing FC return type")
 				self.tree.curBlock = RawAwlFC(self.tree, fcNumber,
 							      retTypeTokens)
+				if fcNumber in self.tree.fcs:
+					raise AwlParserError("Multiple definitions "
+						"of FC %s" % str(fcNumber))
 				self.tree.fcs[fcNumber] = self.tree.curBlock
 				return
 			if t.tokens[0].upper() == "ORGANIZATION_BLOCK":
@@ -605,6 +614,9 @@ class AwlParser(object):
 					except ValueError:
 						raise AwlParserError("Invalid OB number")
 				self.tree.curBlock = RawAwlOB(self.tree, obNumber)
+				if obNumber in self.tree.obs:
+					raise AwlParserError("Multiple definitions "
+						"of OB %s" % str(obNumber))
 				self.tree.obs[obNumber] = self.tree.curBlock
 				return
 		except IndexError as e:
@@ -651,9 +663,11 @@ class AwlParser(object):
 				fbNumber = int(t.tokens[1], 10)
 			except ValueError:
 				raise AwlParserError("Invalid FB/SFB binding")
-			self.tree.curBlock.fb = RawAwlDB.FBRef(fbName = fbName,
-							       fbNumber = fbNumber,
+			self.tree.curBlock.fb = RawAwlDB.FBRef(fbNumber = fbNumber,
 							       isSFB = (name == "SFB"))
+		elif name.startswith('"') and name.endswith('"'):
+			fbSymbol = name[1:-1]
+			self.tree.curBlock.fb = RawAwlDB.FBRef(fbSymbol = fbSymbol)
 		else:
 			raise AwlParserError("In DB header: Unknown token: %s" % name)
 
