@@ -4,8 +4,8 @@ import awlsim.cython_helper as __cython
 
 if __cython.shouldUseCython():
 	try:
-		from awlsim_cython.coreserver.all_modules import *
+		from awlsim_cython.coreserver.all_modules import *	#<no-cython-patch
 	except ImportError as e:
 		__cython.cythonImportError("coreserver", str(e))
 if not __cython.shouldUseCython():
-	from awlsim.coreserver.all_modules import *
+	from awlsim.coreserver.all_modules import *			#<no-cython-patch
