@@ -66,18 +66,22 @@ class CpuWidget(QWidget):
 
 		group = QGroupBox("Add window", self)
 		group.setLayout(QGridLayout(group))
-		self.newCpuStateButton = QPushButton("CPU", group)
-		group.layout().addWidget(self.newCpuStateButton, 0, 0)
-		self.newLCDButton = QPushButton("LCD", group)
-		group.layout().addWidget(self.newLCDButton, 0, 1)
-		self.newDBButton = QPushButton("DB", group)
-		group.layout().addWidget(self.newDBButton, 0, 2)
 		self.newEButton = QPushButton("E (I)", group)
-		group.layout().addWidget(self.newEButton, 1, 0)
+		group.layout().addWidget(self.newEButton, 0, 0)
 		self.newAButton = QPushButton("A (Q)", group)
-		group.layout().addWidget(self.newAButton, 1, 1)
+		group.layout().addWidget(self.newAButton, 0, 1)
 		self.newMButton = QPushButton("M", group)
-		group.layout().addWidget(self.newMButton, 1, 2)
+		group.layout().addWidget(self.newMButton, 0, 2)
+		self.newDBButton = QPushButton("DB", group)
+		group.layout().addWidget(self.newDBButton, 1, 0)
+		self.newTButton = QPushButton("T", group)
+		group.layout().addWidget(self.newTButton, 1, 1)
+		self.newZButton = QPushButton("Z (C)", group)
+		group.layout().addWidget(self.newZButton, 1, 2)
+		self.newCpuStateButton = QPushButton("CPU", group)
+		group.layout().addWidget(self.newCpuStateButton, 2, 0)
+		self.newLCDButton = QPushButton("LCD", group)
+		group.layout().addWidget(self.newLCDButton, 2, 1)
 		self.layout().addWidget(group, 0, 1)
 
 		self.stateWs = StateWorkspace(self)
@@ -94,6 +98,8 @@ class CpuWidget(QWidget):
 		self.newEButton.released.connect(self.__newWin_E)
 		self.newAButton.released.connect(self.__newWin_A)
 		self.newMButton.released.connect(self.__newWin_M)
+		self.newTButton.released.connect(self.__newWin_T)
+		self.newZButton.released.connect(self.__newWin_Z)
 		self.newLCDButton.released.connect(self.__newWin_LCD)
 
 		self.__newWin_CPU()
@@ -129,6 +135,14 @@ class CpuWidget(QWidget):
 					   AbstractDisplayWidget.ADDRSPACE_M,
 					   self))
 
+	def __newWin_T(self):
+		self.__addWindow(State_Timer(self.mainWidget.getSimClient(),
+					     self))
+
+	def __newWin_Z(self):
+		self.__addWindow(State_Counter(self.mainWidget.getSimClient(),
+					       self))
+
 	def __newWin_LCD(self):
 		self.__addWindow(State_LCD(self.mainWidget.getSimClient(), self))
 
@@ -195,7 +209,7 @@ class CpuWidget(QWidget):
 					#      before our server is able to allocate it.
 					if isWinStandalone:
 						# Run the py2exe standalone server process
-						client.spawnServer(serverExecutable = "awlsim-backend-server.exe",
+						client.spawnServer(serverExecutable = "awlsim-server-module.exe",
 								   listenHost = host,
 								   listenPort = port)
 					else:
