@@ -124,6 +124,8 @@ class EditWidget(QPlainTextEdit):
 		self.lineNumWidget = LineNumSubWidget(self)
 		self.cpuStatsWidget = CpuStatsSubWidget(self)
 
+		self.__source = AwlSource(identNr = AwlSource.newIdentNr(),
+					  name = "Unnamed source")
 		self.__runStateCopy = CpuWidget.STATE_STOP
 		self.__nextHdrUpdate = 0
 		self.__hdrAniStat = 0
@@ -142,6 +144,49 @@ class EditWidget(QPlainTextEdit):
 		self.lineNumWidget.wasScrolled.connect(self.__forwardWheelEvent)
 		self.cpuStatsWidget.wasScrolled.connect(self.__forwardWheelEvent)
 
+	def setSource(self, source):
+		self.__textChangeBlocked += 1
+		try:
+			self.__source = source.dup()
+			self.__source.sourceBytes = b""
+			sourceBytes = source.sourceBytes
+			try:
+				sourceText = sourceBytes.decode(AwlParser.TEXT_ENCODING,
+								errors="strict")
+			except UnicodeError:
+				MessageBox.error(self, "The AWL/STL code contains "
+					"non-%s-characters. These were ignored and stripped "
+					"from the code." % AwlParser.TEXT_ENCODING)
+				sourceText = sourceBytes.decode(AwlParser.TEXT_ENCODING,
+								errors="ignore")
+			self.setPlainText(sourceText)
+			self.resetCpuStats()
+		finally:
+			self.__textChangeBlocked -= 1
+
+	def getFullSource(self):
+		source = self.__source.dup()
+		sourceText = self.toPlainText()
+		# Convert to DOS-style line endings
+		sourceText = "\r\n".join(sourceText.splitlines()) + "\r\n"
+		# Convert to binary
+		try:
+			sourceBytes = sourceText.encode(AwlParser.TEXT_ENCODING,
+							errors="strict")
+			source.sourceBytes = sourceBytes
+		except UnicodeError:
+			MessageBox.error(self, "The AWL/STL code contains "
+				"non-%s-characters. These were ignored and stripped "
+				"from the code." % AwlParser.TEXT_ENCODING)
+			sourceBytes = sourceText.encode(AwlParser.TEXT_ENCODING,
+							errors="ignore")
+			source.sourceBytes = sourceBytes
+			self.setSource(source)
+		return source
+
+	def getSourceRef(self):
+		return self.__source
+
 	def runStateChanged(self, newState):
 		self.__runStateCopy = newState
 		if newState == CpuWidget.STATE_INIT:
@@ -210,6 +255,9 @@ class EditWidget(QPlainTextEdit):
 		# insnDumpMsg => AwlSimMessage_INSNDUMP instance
 		if not self.__cpuStatsEnabled:
 			return
+		if insnDumpMsg.sourceId != self.__source.identNr:
+			# Discard old messages that were still in the queue.
+			return
 		# Save the instruction dump
 		self.__lineCpuStats[insnDumpMsg.lineNr] =\
 			CpuStatsEntry(self.__cpuStatsStamp,
@@ -407,12 +455,3 @@ class EditWidget(QPlainTextEdit):
 			return
 		self.codeChanged.emit()
 		self.resetCpuStats()
-
-	def loadCode(self, code):
-		self.__textChangeBlocked += 1
-		self.setPlainText(code)
-		self.resetCpuStats()
-		self.__textChangeBlocked -= 1
-
-	def getCode(self):
-		return self.toPlainText()
